@@ -23,7 +23,6 @@
   \brief The RealMedia file format library
   \author Moritz Bunkus <moritz@bunkus.org>
 
-  $Id: librmff.h 2711 2005-01-12 15:03:47Z mosu $
 */
 
 /** \mainpage
@@ -35,7 +34,7 @@
   files. It does not contain any codecs for audio/video handling.
 
   You can find a description of the RealMedia file format at
-  http://www.pcisys.net/~melanson/codecs/rmff.htm
+  http://wiki.multimedia.cx/index.php?title=RealMedia
 
   \section License
 
@@ -152,7 +151,6 @@
   }
   \endcode
 
-
   \section packed_video_frames Packed video frames
 
   The RealVideo frames are not stored one-complete-frame in one packet
