@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: aac_common.cpp 3336 2006-11-03 16:20:12Z mosu $
-
    helper function for AAC data
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -199,9 +197,9 @@ parse_aac_data(unsigned char *data,
   if (size < 2)
     return false;
 
-  mxverb(4, "parse_aac_data: size %d, data: 0x", size);
+  mxverb(4, boost::format("parse_aac_data: size %1%, data: 0x") % size);
   for (i = 0; i < size; i++)
-    mxverb(4, "%02x ", data[i]);
+    mxverb(4, boost::format("%|1$02x| ") % data[i]);
   mxverb(4, "\n");
 
   profile = data[0] >> 3;
