@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: chapter_writer.cpp 2711 2005-01-12 15:03:47Z mosu $
-
    XML chapter writer functions
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -61,17 +59,13 @@ static vector<chapter_entry_c> chapter_entries;
 static void
 handle_name(int level,
             const string &name) {
-  int i, j;
-  vector<chapter_entry_c>::iterator itr;
+  int i;
 
   for (i = 0; i < chapter_start_times.size(); i++) {
     chapter_entry_c &e = chapter_start_times[i];
     if (e.level == level) {
       chapter_entries.push_back(chapter_entry_c(name, e.start, level));
-      itr = chapter_start_times.begin();
-      for (j = 0; j < i; j++)
-        itr++;
-      chapter_start_times.erase(itr);
+      chapter_start_times.erase(chapter_start_times.begin() + i);
       return;
     }
   }
@@ -82,17 +76,13 @@ handle_name(int level,
 static void
 handle_start_time(int level,
                   int64_t start_time) {
-  int i, j;
-  vector<chapter_entry_c>::iterator itr;
+  int i;
 
   for (i = 0; i < chapter_names.size(); i++) {
     chapter_entry_c &e = chapter_names[i];
     if (e.level == level) {
       chapter_entries.push_back(chapter_entry_c(e.name, start_time, level));
-      itr = chapter_names.begin();
-      for (j = 0; j < i; j++)
-        itr++;
-      chapter_names.erase(itr);
+      chapter_names.erase(chapter_names.begin() + i);
       return;
     }
   }
@@ -186,11 +176,9 @@ write_chapters_simple(int &chapter_num,
 
   for (i = 0; i < chapter_entries.size(); i++) {
     v = chapter_entries[i].start;
-    out->printf("CHAPTER%02d=%02lld:%02lld:%02lld.%03lld\n", chapter_num,
-                (v / 1000 / 60 / 60), (v / 1000 / 60) % 60,
-                (v / 1000) % 60, v % 1000);
-    out->printf("CHAPTER%02dNAME=%s\n", chapter_num,
-                chapter_entries[i].name.c_str());
+    out->puts(boost::format("CHAPTER%|1$02d|=%|2$02d|:%|3$02d|:%|4$02d|.%|5$03d|\n")
+              % chapter_num % (v / 1000 / 60 / 60) % ((v / 1000 / 60) % 60) % ((v / 1000) % 60) % (v % 1000));
+    out->puts(boost::format("CHAPTER%|1$02d|NAME=%2%\n") % chapter_num % chapter_entries[i].name);
     chapter_num++;
   }
 
@@ -209,8 +197,8 @@ pt(xml_writer_cb_t *cb,
   int i;
 
   for (i = 0; i < cb->level; i++)
-    cb->out->printf("  ");
-  cb->out->printf("%s", tag);
+    cb->out->puts("  ");
+  cb->out->puts(tag);
 }
 
 static int
@@ -221,7 +209,7 @@ cet_index(const char *name) {
     if (!strcmp(name, chapter_elements[i].name))
       return i;
 
-  assert(false);
+  mxerror(boost::format(Y("cet_index: '%1%' not found\n")) % name);
   return -1;
 }
 
