@@ -8,16 +8,18 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: chapters.cpp 2979 2005-07-07 14:09:27Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
+#include "os.h"
+
 #include <ctype.h>
 #include <stdarg.h>
 
 #include <cassert>
 #include <string>
+#include <boost/regex.hpp>
 
 #include <matroska/KaxChapters.h>
 
@@ -33,69 +35,22 @@ string default_chapter_language;
 /** The default country for all chapter entries that don't have their own. */
 string default_chapter_country;
 
-/** Is the current char an equal sign? */
-#define isequal(s) (*(s) == '=')
-/** Is the current char a colon, comman or a dot? */
-#define isseparator(s) ((':' == *(s)) || (',' == *(s)) || ('.' == *(s)))
-/** Do we have two consecutive digits? */
-#define istwodigits(s) (isdigit(*(s)) && isdigit(*(s + 1)))
-/** Do we have three consecutive digits? */
-#define isthreedigits(s) (istwodigits(s) && isdigit(*(s + 2)))
-/** Does \c s point to the string "CHAPTER"? */
-#define ischapter(s) (!strncmp("CHAPTER", (s), 7))
-/** Does \c s point to the string "NAME"? */
-#define isname(s) (!strncmp("NAME", (s), 4))
-/** Does \c s point to a valid OGM style chapter timecode entry? */
-#define ischapterline(s) ((strlen(s) == 22) && \
-                          ischapter(s) && \
-                          istwodigits(s + 7) && \
-                          isequal(s + 9) && \
-                          istwodigits(s + 10) && \
-                          isseparator(s + 12) && \
-                          istwodigits(s + 13) && \
-                          isseparator(s + 15) && \
-                          istwodigits(s + 16) && \
-                          isseparator(s + 18) && \
-                          isthreedigits(s + 19))
-/** Does \c s point to a valid OGM style chapter name entry? */
-#define ischapternameline(s) ((strlen(s) >= 14) && \
-                          ischapter(s) && \
-                          istwodigits(s + 7) && \
-                          isname(s + 9) && \
-                          isequal(s + 13))
+#define SIMCHAP_RE_TIMECODE_LINE "^\\s*CHAPTER\\d+\\s*=\\s*(\\d+)\\s*:\\s*(\\d+)\\s*:\\s*(\\d+)\\s*[\\.,]\\s*(\\d+)"
+#define SIMCHAP_RE_TIMECODE      "^\\s*CHAPTER\\d+\\s*=(.*)"
+#define SIMCHAP_RE_NAME_LINE     "^\\s*CHAPTER\\d+NAME\\s*=(.*)"
 
-/** \brief Format an error message and throw an exception.
+/** \brief Throw a special chapter parser exception.
 
-   A \c printf like function that throws an ::error_c exception with
-   the formatted message.
-
-   The parameters are checked for validity.
-
-   \param fmt The \c printf like format.
-   \param ... Optional arguments for the format.
+   \param error The error message.
 */
-static void
-chapter_error(const char *fmt,
-              ...) {
-  va_list ap;
-  string new_fmt;
-  char *new_error;
-  int len;
+inline void
+chapter_error(const std::string &error) {
+  throw error_c(boost::format(Y("Simple chapter parser: %1%\n")) % error);
+}
 
-  assert(fmt != NULL);
-
-  len = strlen("Error: Simple chapter parser: ");
-  va_start(ap, fmt);
-  fix_format(fmt, new_fmt);
-  len += get_varg_len(new_fmt.c_str(), ap);
-  new_error = (char *)safemalloc(len + 2);
-  strcpy(new_error, "Error: Simple chapter parser: ");
-  vsprintf(&new_error[strlen(new_error)], new_fmt.c_str(), ap);
-  strcat(new_error, "\n");
-  va_end(ap);
-  new_fmt = new_error;
-  safefree(new_error);
-  throw error_c(new_fmt);
+inline void
+chapter_error(const boost::format &format) {
+  chapter_error(format.str());
 }
 
 /** \brief Reads the start of a file and checks for OGM style comments.
@@ -113,6 +68,10 @@ chapter_error(const char *fmt,
 */
 bool
 probe_simple_chapters(mm_text_io_c *in) {
+  boost::regex timecode_line_re(SIMCHAP_RE_TIMECODE_LINE, boost::regex::perl);
+  boost::regex name_line_re(    SIMCHAP_RE_NAME_LINE,     boost::regex::perl);
+  boost::match_results<string::const_iterator> matches;
+
   string line;
 
   assert(in != NULL);
@@ -120,21 +79,18 @@ probe_simple_chapters(mm_text_io_c *in) {
   in->setFilePointer(0);
   while (in->getline2(line)) {
     strip(line);
-    if (line.length() == 0)
+    if (line.empty())
       continue;
 
-    if (!ischapterline(line.c_str()))
+    if (!boost::regex_search(line, timecode_line_re))
       return false;
 
     while (in->getline2(line)) {
       strip(line);
-      if (line.length() == 0)
+      if (line.empty())
         continue;
 
-      if (!ischapternameline(line.c_str()))
-        return false;
-
-      return true;
+      return boost::regex_search(line, name_line_re);
     }
 
     return false;
@@ -226,6 +182,11 @@ parse_simple_chapters(mm_text_io_c *in,
   } else
     use_language = language;
 
+  boost::regex timecode_line_re(SIMCHAP_RE_TIMECODE_LINE, boost::regex::perl);
+  boost::regex timecode_re(     SIMCHAP_RE_TIMECODE,      boost::regex::perl);
+  boost::regex name_line_re(    SIMCHAP_RE_NAME_LINE,     boost::regex::perl);
+  boost::match_results<string::const_iterator> matches;
+
   try {
     while (in->getline2(line)) {
       strip(line);
@@ -233,26 +194,29 @@ parse_simple_chapters(mm_text_io_c *in,
         continue;
 
       if (mode == 0) {
-        if (!ischapterline(line.c_str()))
-          chapter_error("'%s' is not a CHAPTERxx=... line.", line.c_str());
-        parse_int(line.substr(10, 2), hour);
-        parse_int(line.substr(13, 2), minute);
-        parse_int(line.substr(16, 2), second);
-        parse_int(line.substr(19, 3), msecs);
+        if (!boost::regex_match(line, matches, timecode_line_re))
+          chapter_error(boost::format(Y("'%1%' is not a CHAPTERxx=... line.")) % line);
+        parse_int(matches[1].str(), hour);
+        parse_int(matches[2].str(), minute);
+        parse_int(matches[3].str(), second);
+        parse_int(matches[4].str(), msecs);
         if (minute > 59)
-          chapter_error("Invalid minute: %d", minute);
+          chapter_error(boost::format(Y("Invalid minute: %1%")) % minute);
         if (second > 59)
-          chapter_error("Invalid second: %d", second);
+          chapter_error(boost::format(Y("Invalid second: %1%")) % second);
         start = msecs + second * 1000 + minute * 1000 * 60 +
           hour * 1000 * 60 * 60;
         mode = 1;
-        s_timecode = line.substr(10);
+
+        if (!boost::regex_match(line, matches, timecode_re))
+          chapter_error(boost::format(Y("'%1%' is not a CHAPTERxx=... line.")) % line);
+        s_timecode = matches[1].str();
 
       } else {
-        if (!ischapternameline(line.c_str()))
-          chapter_error("'%s' is not a CHAPTERxxNAME=... line.", line.c_str());
-        name = line.substr(14);
-        if (name == "")
+        if (!boost::regex_match(line, matches, name_line_re))
+          chapter_error(boost::format(Y("'%1%' is not a CHAPTERxxNAME=... line.")) % line);
+        name = matches[1].str();
+        if (name.empty())
           name = s_timecode;
         mode = 0;
 
@@ -364,16 +328,14 @@ parse_chapters(const string &file_name,
       delete in;
     if (exception_on_error)
       throw;
-    mxerror("Could not parse the chapters in '%s': %s\n", file_name.c_str(),
-            e.get_error().c_str());
+    mxerror(boost::format(Y("Could not parse the chapters in '%1%': %2%\n")) % file_name % e.get_error());
   } catch (...) {
     if (in != NULL)
       delete in;
     if (exception_on_error)
-      throw error_c(mxsprintf("Could not open '%s' for reading.\n",
-                              file_name.c_str()));
+      throw error_c(boost::format(Y("Could not open '%1%' for reading.\n")) % file_name);
     else
-      mxerror("Could not open '%s' for reading.\n", file_name.c_str());
+      mxerror(boost::format(Y("Could not open '%1%' for reading.\n")) % file_name);
   }
   return result;
 }
@@ -442,13 +404,11 @@ parse_chapters(mm_text_io_c *in,
       return parse_xml_chapters(in, min_tc, max_tc, offset,
                                 exception_on_error);
 
-    throw error_c(mxsprintf("Unknown chapter file format in '%s'. It does not "
-                            "contain a supported chapter format.\n",
-                            in->get_file_name().c_str()));
+    throw error_c(boost::format(Y("Unknown chapter file format in '%1%'. It does not contain a supported chapter format.\n")) % in->get_file_name());
   } catch (error_c e) {
     if (exception_on_error)
       throw e;
-    mxerror("%s", e.get_error().c_str());
+    mxerror(e.get_error());
   }
 
   return NULL;
@@ -714,9 +674,9 @@ remove_entries(int64_t min_tc,
         (entries[i].end > min_tc))
       entries[i].spans = true;
 
-    mxverb(3, "remove_chapters: entries[%d]: remove %d spans %d start %lld "
-           "end %lld\n", i, entries[i].remove, entries[i].spans,
-           entries[i].start, entries[i].end);
+    mxverb(3,
+           boost::format("remove_chapters: entries[%1%]: remove %2% spans %3% start %4% end %5%\n")
+           % i % entries[i].remove % entries[i].spans % entries[i].start % entries[i].end);
 
     // Spanning entries must be kept, and their start timecode must be
     // adjusted. Entries that are to be deleted will be deleted later and
@@ -790,8 +750,7 @@ merge_chapter_entries(EbmlMaster &master) {
     start_tc = get_chapter_start(*atom, 0);
     end_tc = get_chapter_end(*atom);
 
-    mxverb(3, "chapters: merge_entries: looking for %lld with %lld, %lld\n",
-           uid, start_tc, end_tc);
+    mxverb(3, boost::format("chapters: merge_entries: looking for %1% with %2%, %3%\n") % uid % start_tc % end_tc);
 
     // Now iterate over all remaining atoms and find those with the same
     // UID.
@@ -828,9 +787,7 @@ merge_chapter_entries(EbmlMaster &master) {
       if ((-1 == end_tc) || (merge_end_tc > end_tc))
         end_tc = merge_end_tc;
 
-      mxverb(3, "chapters: merge_entries:   found one at %d with %lld, %lld; "
-             "merged to %lld, %lld\n", k, merge_start_tc, merge_end_tc,
-             start_tc, end_tc);
+      mxverb(3, boost::format("chapters: merge_entries:   found one at %1% with %2%, %3%; merged to %4%, %5%\n") % k % merge_start_tc % merge_end_tc % start_tc % end_tc);
 
       // Finally remove the entry itself.
       delete master[k];
