@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common.cpp 3978 2008-10-09 07:50:55Z mosu $
-
    helper functions, common variables
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -439,6 +437,17 @@ get_local_charset() {
   return lc_charset;
 }
 
+void
+init_locales() {
+#if ! defined(SYS_WINDOWS) && defined(HAVE_LIBINTL_H)
+  if (setlocale(LC_MESSAGES, "") == NULL)
+    mxerror("The locale could not be set properly. Check the LANG, LC_ALL and LC_MESSAGES environment variables.\n");
+  bindtextdomain("mkvtoolnix", MTX_LOCALE_DIR);
+  textdomain("mkvtoolnix");
+  bind_textdomain_codeset("mkvtoolnix", "UTF-8");
+#endif
+}
+
 int
 utf8_init(const string &charset) {
   string lc_charset;
@@ -667,7 +676,7 @@ _safemalloc(size_t size,
 
   mem = malloc(size);
   if (mem == NULL)
-    mxerror(boost::format(Y("common.cpp/safemalloc() called from file %1%, line %2%: malloc() returned NULL for a size of %3% bytes.")) % file % line % size);
+    mxerror(boost::format(Y("common.cpp/safemalloc() called from file %1%, line %2%: malloc() returned NULL for a size of %3% bytes.\n")) % file % line % size);
 
   return mem;
 }
@@ -682,7 +691,7 @@ _saferealloc(void *mem,
     size = 1;
   mem = realloc(mem, size);
   if (mem == NULL)
-    mxerror(boost::format(Y("common.cpp/saferealloc() called from file %1%, line %2%: realloc() returned NULL for a size of %3% bytes.")) % file % line % size);
+    mxerror(boost::format(Y("common.cpp/saferealloc() called from file %1%, line %2%: realloc() returned NULL for a size of %3% bytes.\n")) % file % line % size);
 
   return mem;
 }
@@ -695,7 +704,7 @@ safefree(void *p) {
 
 void
 dump_malloc_report() {
-  mxinfo(boost::format(Y("%1% bytes malloced, %2% bytes duplicated\n")) % (_safemalloced - _safedupped) % _safedupped);
+  mxinfo(boost::format("%1% bytes malloced, %2% bytes duplicated\n") % (_safemalloced - _safedupped) % _safedupped);
 }
 
 /*
@@ -829,6 +838,8 @@ escape(const string &source) {
       dst += "\\2";               // Yes, this IS a trick ;)
     else if (*src == ' ')
       dst += "\\s";
+    else if (*src == ':')
+      dst += "\\c";
     else
       dst += *src;
   }
@@ -852,6 +863,8 @@ unescape(const string &source) {
           dst += '"';
         else if (*next_char == 's')
           dst += ' ';
+        else if (*next_char == 'c')
+          dst += ':';
         else
           dst += *next_char;
         src++;
@@ -1399,7 +1412,7 @@ read_args_from_file(vector<string> &args,
   try {
     mm_io = new mm_text_io_c(new mm_file_io_c(filename));
   } catch (...) {
-    mxerror(boost::format(Y("The file '%1%' could not be opened for reading command line arguments.")) % filename);
+    mxerror(boost::format(Y("The file '%1%' could not be opened for reading command line arguments.\n")) % filename);
   }
 
   skip_next = false;
