@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: common_memory.h 3757 2008-02-27 14:09:19Z mosu $
-
    class definition for memory handling classes
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -152,7 +150,7 @@ public:
   };
 
   memory_slice_cursor_c(const memory_slice_cursor_c &) {
-    die("memory_slice_cursor_c copy c'tor: Must not be used!");
+    mxerror(Y("memory_slice_cursor_c copy c'tor: Must not be used!"));
   };
 
   ~memory_slice_cursor_c() {
