@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: extern_data.cpp 3540 2007-06-30 09:53:55Z mosu $
-
    Data for ComboBoxes in mmg and other occurences
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -18,6 +16,10 @@
 #include "common.h"
 #include "extern_data.h"
 
+#ifdef SYS_WINDOWS
+# include "os_windows.h"
+#endif
+
 #if HAVE_MAGIC_H
 extern "C" {
 #include <magic.h>
@@ -2282,7 +2284,7 @@ const mime_type_t mime_types[] = {
   {"text/iuls", "uls"},
   {"text/mathml", "mml"},
   {"text/parityfec", ""},
-  {"text/plain", "asc txt text diff cue"},
+  {"text/plain", "asc avs txt text diff cue"},
   {"text/prs.lines.tag", ""},
   {"text/rfc822-headers", ""},
   {"text/richtext", "rtx"},
@@ -2642,8 +2644,24 @@ guess_mime_type(string ext,
   if (!is_file)
     return guess_mime_type_by_ext(ext);
 
-  m = magic_open(MAGIC_MIME | MAGIC_SYMLINK);
-  magic_load(m, NULL);
+  // In newer versions of libmagic MAGIC_MIME is declared as MAGIC_MIME_TYPE | MAGIC_MIME_ENCODING.
+  // Older versions don't know MAGIC_MIME_TYPE, though -- the old MAGIC_MIME is the new MAGIC_MIME_TYPE,
+  // and the new MAGIC_MIME has been redefined.
+#ifdef MAGIC_MIME_TYPE
+  m = magic_open(MAGIC_MIME_TYPE | MAGIC_SYMLINK);
+#else
+  m = magic_open(MAGIC_MIME      | MAGIC_SYMLINK);
+#endif
+
+#ifdef SYS_WINDOWS
+  std::string magic_filename = get_installation_path() + "\\data\\magic";
+  if (!m || (-1 == magic_load(m, magic_filename.c_str())))
+    return guess_mime_type_by_ext(ext);
+#else
+  if (!m || (-1 == magic_load(m, NULL)))
+    return guess_mime_type_by_ext(ext);
+#endif
+
   ret = magic_file(m, ext.c_str());
   magic_close(m);
 
