@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: iso639.cpp 3959 2008-10-04 22:00:39Z mosu $
-
    ISO639 language definitions, lookup functions
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -24,10 +22,12 @@ const iso639_language_t iso639_languages[] = {
   { "Achinese",                                       "ace", NULL, NULL  },
   { "Acoli",                                          "ach", NULL, NULL  },
   { "Adangme",                                        "ada", NULL, NULL  },
+  { "Adyghe; Adygei",                                 "ady", NULL, NULL  },
   { "Afar",                                           "aar", "aa", NULL  },
   { "Afrihili",                                       "afh", NULL, NULL  },
   { "Afrikaans",                                      "afr", "af", NULL  },
   { "Afro-Asiatic (Other)",                           "afa", NULL, NULL  },
+  { "Ainu",                                           "ain", NULL, NULL  },
   { "Akan",                                           "aka", "ak", NULL  },
   { "Akkadian",                                       "akk", NULL, NULL  },
   { "Albanian",                                       "alb", "sq", "sqi" },
@@ -35,6 +35,7 @@ const iso639_language_t iso639_languages[] = {
   { "Algonquian languages",                           "alg", NULL, NULL  },
   { "Altaic (Other)",                                 "tut", NULL, NULL  },
   { "Amharic",                                        "amh", "am", NULL  },
+  { "Angika",                                         "anp", NULL, NULL  },
   { "Apache languages",                               "apa", NULL, NULL  },
   { "Arabic",                                         "ara", "ar", NULL  },
   { "Aragonese",                                      "arg", "an", NULL  },
@@ -43,6 +44,7 @@ const iso639_language_t iso639_languages[] = {
   { "Araucanian",                                     "arn", NULL, NULL  },
   { "Arawak",                                         "arw", NULL, NULL  },
   { "Armenian",                                       "arm", "hy", "hye" },
+  { "Aromanian; Arumanian; Macedo-Romanian",          "rup", NULL, NULL  },
   { "Artificial (Other)",                             "art", NULL, NULL  },
   { "Assamese",                                       "asm", "as", NULL  },
   { "Asturian; Bable",                                "ast", NULL, NULL  },
@@ -76,6 +78,8 @@ const iso639_language_t iso639_languages[] = {
   { "Bikol",                                          "bik", NULL, NULL  },
   { "Bini",                                           "bin", NULL, NULL  },
   { "Bislama",                                        "bis", "bi", NULL  },
+  { "Blin; Bilin",                                    "byn", NULL, NULL  },
+  { "Blissymbols; Blissymbolics; Bliss",              "zbl", NULL, NULL  },
   { "Bokmål, Norwegian; Norwegian Bokmål",          "nob", "nb", NULL  },
   { "Bosnian",                                        "bos", "bs", NULL  },
   { "Braj",                                           "bra", NULL, NULL  },
@@ -107,12 +111,12 @@ const iso639_language_t iso639_languages[] = {
   { "Choctaw",                                        "cho", NULL, NULL  },
   { "Chuang; Zhuang",                                 "zha", "za", NULL  },
   { "Church Slavic; Old Church Slavonic",             "chu", "cu", NULL  },
-  { "Old Church Slavonic; Old Slavonic; ",            "chu", "cu", NULL  },
-  { "Church Slavonic; Old Bulgarian; Church Slavic;", "chu", "cu", NULL  },
-  { "Old Slavonic; Church Slavonic; Old Bulgarian;",  "chu", "cu", NULL  },
   { "Church Slavic; Old Church Slavonic",             "chu", "cu", NULL  },
+  { "Church Slavonic; Old Bulgarian; Church Slavic;", "chu", "cu", NULL  },
   { "Chuukese",                                       "chk", NULL, NULL  },
   { "Chuvash",                                        "chv", "cv", NULL  },
+  { "Classical Newari; Classical Nepal Bhasa",        "nwc", NULL, NULL  },
+  { "Classical Syriac",                               "syc", NULL, NULL  },
   { "Coptic",                                         "cop", NULL, NULL  },
   { "Cornish",                                        "cor", "kw", NULL  },
   { "Corsican",                                       "cos", "co", NULL  },
@@ -122,6 +126,7 @@ const iso639_language_t iso639_languages[] = {
   { "Creoles and pidgins,",                           "cpe", NULL, NULL  },
   { "Creoles and pidgins,",                           "cpf", NULL, NULL  },
   { "Creoles and pidgins,",                           "cpp", NULL, NULL  },
+  { "Crimean Tatar; Crimean Turkish",                 "crh", NULL, NULL  },
   { "Croatian; Hrvatske",                             "scr", "hr", "hrv" },
   { "Cushitic (Other)",                               "cus", NULL, NULL  },
   { "Czech",                                          "cze", "cs", "ces" },
@@ -136,10 +141,11 @@ const iso639_language_t iso639_languages[] = {
   { "Dogrib",                                         "dgr", NULL, NULL  },
   { "Dravidian (Other)",                              "dra", NULL, NULL  },
   { "Duala",                                          "dua", NULL, NULL  },
-  { "Dutch; Flemish",                                 "dut", "nl", "nld" },
   { "Dutch, Middle (ca. 1050-1350)",                  "dum", NULL, NULL  },
+  { "Dutch; Flemish",                                 "dut", "nl", "nld" },
   { "Dyula",                                          "dyu", NULL, NULL  },
   { "Dzongkha",                                       "dzo", "dz", NULL  },
+  { "Eastern Frisian",                                "frs", NULL, NULL  },
   { "Efik",                                           "efi", NULL, NULL  },
   { "Egyptian (Ancient)",                             "egy", NULL, NULL  },
   { "Ekajuk",                                         "eka", NULL, NULL  },
@@ -147,6 +153,7 @@ const iso639_language_t iso639_languages[] = {
   { "English",                                        "eng", "en", NULL  },
   { "English, Middle (1100-1500)",                    "enm", NULL, NULL  },
   { "English, Old (ca.450-1100)",                     "ang", NULL, NULL  },
+  { "Erzya",                                          "myv", NULL, NULL  },
   { "Esperanto",                                      "epo", "eo", NULL  },
   { "Estonian",                                       "est", "et", NULL  },
   { "Ewe",                                            "ewe", "ee", NULL  },
@@ -155,6 +162,7 @@ const iso639_language_t iso639_languages[] = {
   { "Fanti",                                          "fat", NULL, NULL  },
   { "Faroese",                                        "fao", "fo", NULL  },
   { "Fijian",                                         "fij", "fj", NULL  },
+  { "Filipino; Pilipino",                             "fil", NULL, NULL  },
   { "Finnish",                                        "fin", "fi", NULL  },
   { "Finno-Ugrian (Other)",                           "fiu", NULL, NULL  },
   { "Fon",                                            "fon", NULL, NULL  },
@@ -183,13 +191,14 @@ const iso639_language_t iso639_languages[] = {
   { "Gorontalo",                                      "gor", NULL, NULL  },
   { "Gothic",                                         "got", NULL, NULL  },
   { "Grebo",                                          "grb", NULL, NULL  },
-  { "Greek, Ancient (to 1453)",                       "grc", NULL, NULL  },
   { "Greek",                                          "gre", "el", "ell" },
+  { "Greek, Ancient (to 1453)",                       "grc", NULL, NULL  },
   { "Greenlandic; Kalaallisut",                       "kal", "kl", NULL  },
   { "Guarani",                                        "grn", "gn", NULL  },
   { "Gujarati",                                       "guj", "gu", NULL  },
   { "GwichŽin",                                      "gwi", NULL, NULL  },
   { "Haida",                                          "hai", NULL, NULL  },
+  { "Haitian; Haitian Creole",                        "hat", NULL, NULL  },
   { "Hausa",                                          "hau", "ha", NULL  },
   { "Hawaiian",                                       "haw", NULL, NULL  },
   { "Hebrew",                                         "heb", "he", NULL  },
@@ -232,12 +241,16 @@ const iso639_language_t iso639_languages[] = {
   { "Kabyle",                                         "kab", NULL, NULL  },
   { "Kachin",                                         "kac", NULL, NULL  },
   { "Kalaallisut; Greenlandic",                       "kal", "kl", NULL  },
+  { "Kalmyk; Oirat",                                  "xal", NULL, NULL  },
   { "Kamba",                                          "kam", NULL, NULL  },
   { "Kannada",                                        "kan", "kn", NULL  },
   { "Kanuri",                                         "kau", "kr", NULL  },
   { "Kara-Kalpak",                                    "kaa", NULL, NULL  },
+  { "Karachay-Balkar",                                "krc", NULL, NULL  },
+  { "Karelian",                                       "krl", NULL, NULL  },
   { "Karen",                                          "kar", NULL, NULL  },
   { "Kashmiri",                                       "kas", "ks", NULL  },
+  { "Kashubian",                                      "csb", NULL, NULL  },
   { "Kawi",                                           "kaw", NULL, NULL  },
   { "Kazakh",                                         "kaz", "kk", NULL  },
   { "Khasi",                                          "kha", NULL, NULL  },
@@ -275,8 +288,10 @@ const iso639_language_t iso639_languages[] = {
   { "Limburgish; Limburger; Limburgan",               "lim", "li", NULL  },
   { "Lingala",                                        "lin", "ln", NULL  },
   { "Lithuanian",                                     "lit", "lt", NULL  },
+  { "Lojban",                                         "jbo", NULL, NULL  },
   { "Low German; Low Saxon; German, Low; Saxon, Low", "nds", NULL, NULL  },
   { "Low Saxon; Low German; Saxon, Low; German, Low", "nds", NULL, NULL  },
+  { "Lower Sorbian",                                  "dsb", NULL, NULL  },
   { "Lozi",                                           "loz", NULL, NULL  },
   { "Luba-Katanga",                                   "lub", "lu", NULL  },
   { "Luba-Lulua",                                     "lua", NULL, NULL  },
@@ -311,8 +326,10 @@ const iso639_language_t iso639_languages[] = {
   { "Mende",                                          "men", NULL, NULL  },
   { "Micmac",                                         "mic", NULL, NULL  },
   { "Minangkabau",                                    "min", NULL, NULL  },
+  { "Mirandese",                                      "mwl", NULL, NULL  },
   { "Miscellaneous languages",                        "mis", NULL, NULL  },
   { "Mohawk",                                         "moh", NULL, NULL  },
+  { "Moksha",                                         "mdf", NULL, NULL  },
   { "Moldavian",                                      "mol", "mo", NULL  },
   { "Mon-Khmer (Other)",                              "mkh", NULL, NULL  },
   { "Mongo",                                          "lol", NULL, NULL  },
@@ -320,6 +337,7 @@ const iso639_language_t iso639_languages[] = {
   { "Mossi",                                          "mos", NULL, NULL  },
   { "Multiple languages",                             "mul", NULL, NULL  },
   { "Munda languages",                                "mun", NULL, NULL  },
+  { "N'Ko",                                           "nqo", NULL, NULL  },
   { "Nahuatl",                                        "nah", NULL, NULL  },
   { "Nauru",                                          "nau", "na", NULL  },
   { "Navaho, Navajo",                                 "nav", "nv", NULL  },
@@ -334,13 +352,15 @@ const iso639_language_t iso639_languages[] = {
   { "Niger-Kordofanian (Other)",                      "nic", NULL, NULL  },
   { "Nilo-Saharan (Other)",                           "ssa", NULL, NULL  },
   { "Niuean",                                         "niu", NULL, NULL  },
+  { "Nogai",                                          "nog", NULL, NULL  },
   { "Norse, Old",                                     "non", NULL, NULL  },
   { "North American Indian (Other)",                  "nai", NULL, NULL  },
-  { "Northern Sami",                                  "sme", "se", NULL  },
   { "North Ndebele",                                  "nde", "nd", NULL  },
-  { "Norwegian",                                      "nor", "no", NULL  },
+  { "Northern Frisian",                               "frr", NULL, NULL  },
+  { "Northern Sami",                                  "sme", "se", NULL  },
   { "Norwegian Bokmål; Bokmål, Norwegian",          "nob", "nb", NULL  },
   { "Norwegian Nynorsk; Nynorsk, Norwegian",          "nno", "nn", NULL  },
+  { "Norwegian",                                      "nor", "no", NULL  },
   { "Nubian languages",                               "nub", NULL, NULL  },
   { "Nyamwezi",                                       "nym", NULL, NULL  },
   { "Nyanja; Chichewa; Chewa",                        "nya", "ny", NULL  },
@@ -351,6 +371,8 @@ const iso639_language_t iso639_languages[] = {
   { "Occitan (post 1500)",                            "oci", "oc", NULL  },
   { "Ojibwa",                                         "oji", "oj", NULL  },
   { "Old Bulgarian; Old Slavonic; Church Slavonic;",  "chu", "cu", NULL  },
+  { "Old Church Slavonic; Old Slavonic; ",            "chu", "cu", NULL  },
+  { "Old Slavonic; Church Slavonic; Old Bulgarian;",  "chu", "cu", NULL  },
   { "Oriya",                                          "ori", "or", NULL  },
   { "Oromo",                                          "orm", "om", NULL  },
   { "Osage",                                          "osa", NULL, NULL  },
@@ -373,8 +395,8 @@ const iso639_language_t iso639_languages[] = {
   { "Polish",                                         "pol", "pl", NULL  },
   { "Portuguese",                                     "por", "pt", NULL  },
   { "Prakrit languages",                              "pra", NULL, NULL  },
-  { "Provençal; Occitan (post 1500)",                "oci", "oc", NULL  },
   { "Provençal, Old (to 1500)",                      "pro", NULL, NULL  },
+  { "Provençal; Occitan (post 1500)",                "oci", "oc", NULL  },
   { "Pushto",                                         "pus", "ps", NULL  },
   { "Quechua",                                        "que", "qu", NULL  },
   { "Raeto-Romance",                                  "roh", "rm", NULL  },
@@ -406,6 +428,7 @@ const iso639_language_t iso639_languages[] = {
   { "Shan",                                           "shn", NULL, NULL  },
   { "Shona",                                          "sna", "sn", NULL  },
   { "Sichuan Yi",                                     "iii", "ii", NULL  },
+  { "Sicilian",                                       "scn", NULL, NULL  },
   { "Sidamo",                                         "sid", NULL, NULL  },
   { "Sign languages",                                 "sgn", NULL, NULL  },
   { "Siksika",                                        "bla", NULL, NULL  },
@@ -426,9 +449,11 @@ const iso639_language_t iso639_languages[] = {
   { "Sotho, Northern",                                "nso", NULL, NULL  },
   { "Sotho, Southern",                                "sot", "st", NULL  },
   { "South American Indian (Other)",                  "sai", NULL, NULL  },
-  { "Southern Sami",                                  "sma", NULL, NULL  },
   { "South Ndebele",                                  "nbl", "nr", NULL  },
+  { "Southern Altai",                                 "alt", NULL, NULL  },
+  { "Southern Sami",                                  "sma", NULL, NULL  },
   { "Spanish",                                        "spa", "es", NULL  },
+  { "Sranan Tongo",                                   "srn", NULL, NULL  },
   { "Sukuma",                                         "suk", NULL, NULL  },
   { "Sumerian",                                       "sux", NULL, NULL  },
   { "Sundanese",                                      "sun", "su", NULL  },
@@ -436,6 +461,7 @@ const iso639_language_t iso639_languages[] = {
   { "Swahili",                                        "swa", "sw", NULL  },
   { "Swati",                                          "ssw", "ss", NULL  },
   { "Swedish",                                        "swe", "sv", NULL  },
+  { "Swiss German; Alemannic; Alsatian",              "gsw", NULL, NULL  },
   { "Syriac",                                         "syr", NULL, NULL  },
   { "Tagalog",                                        "tgl", "tl", NULL  },
   { "Tahitian",                                       "tah", "ty", NULL  },
@@ -469,11 +495,13 @@ const iso639_language_t iso639_languages[] = {
   { "Tuvalu",                                         "tvl", NULL, NULL  },
   { "Tuvinian",                                       "tyv", NULL, NULL  },
   { "Twi",                                            "twi", "tw", NULL  },
+  { "Udmurt",                                         "udm", NULL, NULL  },
   { "Ugaritic",                                       "uga", NULL, NULL  },
   { "Uighur",                                         "uig", "ug", NULL  },
   { "Ukrainian",                                      "ukr", "uk", NULL  },
   { "Umbundu",                                        "umb", NULL, NULL  },
   { "Undetermined",                                   "und", NULL, NULL  },
+  { "Upper Sorbian",                                  "hsb", NULL, NULL  },
   { "Urdu",                                           "urd", "ur", NULL  },
   { "Uzbek",                                          "uzb", "uz", NULL  },
   { "Vai",                                            "vai", NULL, NULL  },
@@ -497,6 +525,7 @@ const iso639_language_t iso639_languages[] = {
   { "Yupik languages",                                "ypk", NULL, NULL  },
   { "Zande",                                          "znd", NULL, NULL  },
   { "Zapotec",                                        "zap", NULL, NULL  },
+  { "Zaza; Dimili; Dimli; Kirdki; Kirmanjki; Zazaki", "zza", NULL, NULL  },
   { "Zenaga",                                         "zen", NULL, NULL  },
   { "Zhuang; Chuang",                                 "zha", "za", NULL  },
   { "Zulu",                                           "zul", "zu", NULL  },
@@ -626,7 +655,6 @@ map_to_iso639_2_code(const char *s,
         return i;
   }
 
-
   return -1;
 }
 
