@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mm_io.h 3759 2008-02-27 15:32:22Z mosu $
-
    IO callback class definitions
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -99,6 +97,9 @@ public:
   virtual string getline();
   virtual bool getline2(string &s);
   virtual size_t puts(const string &s);
+  inline size_t puts(const boost::format &format) {
+    return puts(format.str());
+  }
   virtual bool write_bom(const string &charset);
   virtual int getch();
 
@@ -109,7 +110,6 @@ public:
 
   virtual void close() = 0;
 
-  virtual int printf(const char *fmt, ...);
   virtual void use_dos_style_newlines(bool yes) {
     dos_style_newlines = yes;
   }
