@@ -5,8 +5,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mkvextract.cpp 3984 2008-10-11 14:11:55Z mosu $
-
    command line parsing, setup
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -257,11 +255,12 @@ parse_args(vector<string> args,
 
     } else if ((mode == MODE_TRACKS) || (mode == MODE_ATTACHMENTS) || (MODE_TIMECODES_V2 == mode)) {
       boost::match_results<string::const_iterator> matches;
-      if (!boost::regex_search(args[i], matches, tid_re))
+      if (!boost::regex_search(args[i], matches, tid_re)) {
         if ((MODE_TRACKS == mode) || (MODE_TIMECODES_V2 == mode))
           mxerror(boost::format(Y("Invalid track ID/file name specification in argument '%1%'.\n")) % args[i]);
         else
           mxerror(boost::format(Y("Invalid attachment ID/file name specification in argument '%1%'.\n")) % args[i]);
+      }
 
       track_spec_t track;
       memset(&track, 0, sizeof(track_spec_t));
@@ -272,11 +271,12 @@ parse_args(vector<string> args,
       if (matches[3].matched)
         output_file_name = matches[3].str();
 
-      if (output_file_name.empty())
+      if (output_file_name.empty()) {
         if (MODE_ATTACHMENTS == mode)
           mxinfo(Y("No output file name specified, will use attachment name.\n"));
         else
           mxerror(boost::format(Y("Missing output file name in argument '%1%'.\n")) % args[i]);
+      }
 
       track.out_name               = safestrdup(output_file_name.c_str());
       track.sub_charset            = safestrdup(sub_charset);
@@ -334,19 +334,13 @@ int
 main(int argc,
      char **argv) {
   init_stdio();
+  init_locales();
   set_usage();
 
 #if defined(SYS_UNIX)
   nice(2);
 #endif
 
-#if defined(HAVE_LIBINTL_H)
-  if (setlocale(LC_MESSAGES, "") == NULL)
-    mxerror("The locale could not be set properly. Check the LANG, LC_ALL and LC_MESSAGES environment variables.\n");
-  bindtextdomain("mkvtoolnix", MTX_LOCALE_DIR);
-  textdomain("mkvtoolnix");
-#endif
-
   mm_file_io_c::setup();
   srand(time(NULL));
   utf8_init("");
