@@ -5,8 +5,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: timecodes_v2.cpp 3984 2008-10-11 14:11:55Z mosu $
-
    extracts timecodes from Matroska files
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -267,7 +265,7 @@ extract_timecodes(const string &file_name,
         uint64_t cluster_tc = 0;
 
         if (0 == verbose)
-          mxinfo(boost::format(Y("Progress: %1%%%\r")) % (int)(in->getFilePointer() * 100 / file_size));
+          mxinfo(boost::format(Y("Progress: %1%%%%2%")) % (int)(in->getFilePointer() * 100 / file_size) % "\r");
 
         upper_lvl_el = 0;
         l2           = es->FindNextElement(l1->Generic().Context, upper_lvl_el, 0xFFFFFFFFL, true, 1);
