@@ -6,17 +6,14 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_aac.cpp 3861 2008-08-27 11:27:04Z mosu $
-
    AAC demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "os.h"
+
+#include <algorithm>
 
 #include "common.h"
 #include "error.h"
@@ -88,21 +85,21 @@ aac_reader_c::aac_reader_c(track_info_c &_ti)
     if (0 < tag_size_end)
       size -= tag_size_end;
 
-    int init_read_len = MXMIN(size - tag_size_start, INITCHUNKSIZE);
+    int init_read_len = std::min(size - tag_size_start, (int64_t)INITCHUNKSIZE);
     chunk             = (unsigned char *)safemalloc(INITCHUNKSIZE);
 
     if (io->read(chunk, init_read_len) != init_read_len)
-      throw error_c(mxsprintf("aac_reader: Could not read %d bytes.", init_read_len));
+      throw error_c(boost::format(Y("aac_reader: Could not read %1% bytes.")) % init_read_len);
 
     io->setFilePointer(tag_size_start, seek_beginning);
 
     if (parse_aac_adif_header(chunk, init_read_len, &aacheader)) {
-      throw error_c("aac_reader: ADIF header files are not supported.");
+      throw error_c(Y("aac_reader: ADIF header files are not supported."));
       adif = 1;
 
     } else {
       if (find_aac_header(chunk, init_read_len, &aacheader, emphasis_present) != 0)
-        throw error_c(mxsprintf("aac_reader: No valid AAC packet found in the first %d bytes.\n", init_read_len));
+        throw error_c(boost::format(Y("aac_reader: No valid AAC packet found in the first %1% bytes.\n")) % init_read_len);
       guess_adts_version();
       adif = 0;
     }
@@ -127,11 +124,11 @@ aac_reader_c::aac_reader_c(track_info_c &_ti)
       sbr_status_set = true;
 
   } catch (...) {
-    throw error_c("aac_reader: Could not open the file.");
+    throw error_c(Y("aac_reader: Could not open the file."));
   }
 
   if (verbose)
-    mxinfo(FMT_FN "Using the AAC demultiplexer.\n", ti.fname.c_str());
+    mxinfo_fn(ti.fname, Y("Using the AAC demultiplexer.\n"));
 }
 
 aac_reader_c::~aac_reader_c() {
@@ -146,19 +143,19 @@ aac_reader_c::create_packetizer(int64_t) {
   if (NPTZR() != 0)
     return;
   if (!sbr_status_set)
-    mxwarn("AAC files may contain HE-AAC / AAC+ / SBR AAC audio. "
-           "This can NOT be detected automatically. Therefore you have to "
-           "specifiy '--aac-is-sbr 0' manually for this input file if the "
-           "file actually contains SBR AAC. The file will be muxed in the "
-           "WRONG way otherwise. Also read mkvmerge's documentation.\n");
+    mxwarn(Y("AAC files may contain HE-AAC / AAC+ / SBR AAC audio. "
+             "This can NOT be detected automatically. Therefore you have to "
+             "specifiy '--aac-is-sbr 0' manually for this input file if the "
+             "file actually contains SBR AAC. The file will be muxed in the "
+             "WRONG way otherwise. Also read mkvmerge's documentation.\n"));
 
-  aacpacketizer = new aac_packetizer_c(this, aacheader.id, aacheader.profile, aacheader.sample_rate, aacheader.channels, ti, emphasis_present);
+  aacpacketizer = new aac_packetizer_c(this, ti, aacheader.id, aacheader.profile, aacheader.sample_rate, aacheader.channels, emphasis_present);
   add_packetizer(aacpacketizer);
 
   if (AAC_PROFILE_SBR == aacheader.profile)
     aacpacketizer->set_audio_output_sampling_freq(aacheader.sample_rate * 2);
 
-  mxinfo(FMT_TID "Using the AAC output module.\n", ti.fname.c_str(), (int64_t)0);
+  mxinfo_tid(ti.fname, 0, Y("Using the AAC output module.\n"));
 }
 
 // Try to guess if the MPEG4 header contains the emphasis field (2 bits)
@@ -191,7 +188,7 @@ file_status_e
 aac_reader_c::read(generic_packetizer_c *,
                    bool) {
   int remaining_bytes = size - io->getFilePointer();
-  int read_len        = MXMIN(INITCHUNKSIZE, remaining_bytes);
+  int read_len        = std::min(INITCHUNKSIZE, remaining_bytes);
   int num_read        = io->read(chunk, read_len);
 
   if (0 > num_read) {
