@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_ac3.cpp 3851 2008-08-24 18:34:08Z mosu $
-
    AC3 demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -15,10 +13,7 @@
 
 #include "os.h"
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include <algorithm>
 
 extern "C" {
 #include <avilib.h>
@@ -64,25 +59,25 @@ ac3_reader_c::ac3_reader_c(track_info_c &_ti)
     if (0 < tag_size_end)
       size -= tag_size_end;
 
-    int init_read_len = MXMIN(size - tag_size_start, AC3_READ_SIZE);
+    int init_read_len = std::min(size - tag_size_start, (int64_t)AC3_READ_SIZE);
 
     if (io->read(chunk->get(), init_read_len) != init_read_len)
-      throw error_c(mxsprintf("ac3_reader: Could not read %d bytes.", AC3_READ_SIZE));
+      throw error_c(boost::format(Y("ac3_reader: Could not read %1% bytes.")) % AC3_READ_SIZE);
 
     io->setFilePointer(tag_size_start, seek_beginning);
 
   } catch (...) {
-    throw error_c("ac3_reader: Could not open the source file.");
+    throw error_c(Y("ac3_reader: Could not open the source file."));
   }
 
-  if (0 > find_ac3_header(chunk->get(), AC3_READ_SIZE, &ac3header))
-    throw error_c(mxsprintf("ac3_reader: No valid AC3 packet found in the first %d bytes.\n", AC3_READ_SIZE));
+  if (0 > find_ac3_header(chunk->get(), AC3_READ_SIZE, &ac3header, true))
+    throw error_c(boost::format(Y("ac3_reader: No valid AC3 packet found in the first %1% bytes.\n")) % AC3_READ_SIZE);
 
   bytes_processed = 0;
   ti.id           = 0;          // ID for this track.
 
   if (verbose)
-    mxinfo(FMT_FN "Using the AC3 demultiplexer.\n", ti.fname.c_str());
+    mxinfo_fn(ti.fname, Y("Using the AC3 demultiplexer.\n"));
 }
 
 ac3_reader_c::~ac3_reader_c() {
@@ -94,16 +89,16 @@ ac3_reader_c::create_packetizer(int64_t) {
   if (NPTZR() != 0)
     return;
 
-  add_packetizer(new ac3_packetizer_c(this, ac3header.sample_rate, ac3header.channels, ac3header.bsid, ti));
-  mxinfo(FMT_TID "Using the %sAC3 output module.\n", ti.fname.c_str(), (int64_t)0, 16 == ac3header.bsid ? "E" : "");
+  add_packetizer(new ac3_packetizer_c(this, ti, ac3header.sample_rate, ac3header.channels, ac3header.bsid));
+  mxinfo_tid(ti.fname, 0, boost::format(Y("Using the %1%AC3 output module.\n")) % (16 == ac3header.bsid ? "E" : ""));
 }
 
 file_status_e
 ac3_reader_c::read(generic_packetizer_c *,
                    bool) {
-  int remaining_bytes = size - io->getFilePointer();
-  int read_len        = MXMIN(AC3_READ_SIZE, remaining_bytes);
-  int num_read        = io->read(chunk->get(), read_len);
+  int64_t remaining_bytes = size - io->getFilePointer();
+  int64_t read_len        = std::min((int64_t)AC3_READ_SIZE, remaining_bytes);
+  int num_read            = io->read(chunk->get(), read_len);
 
   if (0 > num_read) {
     PTZR0->flush();
