@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_mpeg_es.cpp 3953 2008-10-04 18:53:24Z mosu $
-
    MPEG ES (elementary stream) demultiplexer module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -161,7 +159,7 @@ mpeg_es_reader_c::mpeg_es_reader_c(track_info_c &_ti)
       ti.private_size = raw_seq_hdr->GetSize();
     }
 
-    mxverb(2, boost::format(Y("mpeg_es_reader: version %1% width %2% height %3% FPS %4% AR %5%\n")) % version % width % height % frame_rate % aspect_ratio);
+    mxverb(2, boost::format("mpeg_es_reader: version %1% width %2% height %3% FPS %4% AR %5%\n") % version % width % height % frame_rate % aspect_ratio);
 
   } catch (...) {
     throw error_c(Y("mpeg_es_reader: Could not open the file."));
