@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_ogm.cpp 3861 2008-08-27 11:27:04Z mosu $
-
    OGG media stream reader
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -243,7 +241,6 @@ public:
 
 // ---------------------------------------------------------------------------------
 
-
 static counted_ptr<vector<string> >
 extract_vorbis_comments(const memory_cptr &mem) {
   counted_ptr<vector<string> > comments(new vector<string>);
@@ -308,18 +305,18 @@ ogm_reader_c::ogm_reader_c(track_info_c &_ti)
     io        = new mm_file_io_c(ti.fname);
     file_size = io->get_size();
   } catch (...) {
-    throw error_c("ogm_reader: Could not open the source file.");
+    throw error_c(Y("ogm_reader: Could not open the source file."));
   }
   if (!ogm_reader_c::probe_file(io, file_size))
-    throw error_c("ogm_reader: Source is not a valid OGG media file.");
+    throw error_c(Y("ogm_reader: Source is not a valid OGG media file."));
 
   ogg_sync_init(&oy);
 
   if (verbose)
-    mxinfo(FMT_FN "Using the OGG/OGM demultiplexer.\n", ti.fname.c_str());
+    mxinfo_fn(ti.fname, Y("Using the OGG/OGM demultiplexer.\n"));
 
   if (read_headers() <= 0)
-    throw error_c("ogm_reader: Could not read all header packets.");
+    throw error_c(Y("ogm_reader: Could not read all header packets."));
   handle_stream_comments();
 }
 
@@ -359,11 +356,11 @@ ogm_reader_c::read_page(ogg_page *og) {
     if (0 >= np) {
       // np < 0 is the error case. Should not happen with local OGG files.
       if (0 > np)
-        mxwarn("ogm_reader: Could not find the next Ogg page. This indicates a damaged Ogg/Ogm file. Will try to continue.\n");
+        mxwarn_fn(ti.fname, Y("Could not find the next Ogg page. This indicates a damaged Ogg/Ogm file. Will try to continue.\n"));
 
       buf = (unsigned char *)ogg_sync_buffer(&oy, BUFFER_SIZE);
       if (!buf)
-        mxerror("ogm_reader: ogg_sync_buffer failed\n");
+        mxerror_fn(ti.fname, Y("ogg_sync_buffer failed\n"));
 
       if (0 >= (nread = io->read(buf, BUFFER_SIZE)))
         return 0;
@@ -452,7 +449,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
   ogg_packet op;
 
   if (ogg_stream_init(&os, ogg_page_serialno(og))) {
-    mxwarn("ogm_reader: ogg_stream_init for stream number %u failed. Will try to continue and ignore this stream.", (unsigned int)sdemuxers.size());
+    mxwarn_fn(ti.fname, boost::format(Y("ogg_stream_init for stream number %1% failed. Will try to continue and ignore this stream.\n")) % sdemuxers.size());
     return;
   }
 
@@ -479,7 +476,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
   else if ((4 <= op.bytes) && !strncmp((char *)op.packet, "fLaC", 4)) {
 #if !defined(HAVE_FLAC_FORMAT_H)
     if (demuxing_requested('a', sdemuxers.size()))
-      mxerror("mkvmerge has not been compiled with FLAC support but handling of this stream has been requested.\n");
+      mxerror_fn(ti.fname, Y("mkvmerge has not been compiled with FLAC support but handling of this stream has been requested.\n"));
 
     else {
       dmx         = new ogm_demuxer_c(this);
@@ -524,7 +521,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
         dmx = new ogm_a_aac_demuxer_c(this);
 
       else
-        mxwarn("ogm_reader: Unknown audio stream type 0x%04x. Ignoring stream id %u.\n", codec_id, (unsigned int)sdemuxers.size());
+        mxwarn_fn(ti.fname, boost::format(Y("Unknown audio stream type 0x%|1$04x|. Stream ID %2% will be ignored.\n")) % codec_id % sdemuxers.size());
 
     } else if (!strncmp(sth->streamtype, "text", 4))
       dmx = new ogm_s_text_demuxer_c(this);
@@ -542,7 +539,7 @@ ogm_reader_c::handle_new_stream(ogg_page *og) {
 
   dmx->serialno = ogg_page_serialno(og);
   dmx->track_id = sdemuxers.size();
-  dmx->in_use   = demuxing_requested(type[0], dmx->track_id);
+  dmx->in_use   = (type != "unknown") && demuxing_requested(type[0], dmx->track_id);
 
   dmx->packet_data.push_back(memory_cptr(new memory_c((unsigned char *)safememdup(op.packet, op.bytes), op.bytes, true)));
 
@@ -573,8 +570,8 @@ ogm_reader_c::process_page(ogg_page *og) {
   granulepos = ogg_page_granulepos(og);
 
   if ((-1 != granulepos) && (granulepos < dmx->last_granulepos)) {
-    mxwarn(FMT_TID "The timecodes for this stream have been reset in the middle of the file. This is not supported. The current packet will be discarded.\n",
-           ti.fname.c_str(), (int64_t)dmx->track_id);
+    mxwarn_tid(ti.fname, dmx->track_id,
+               Y("The timecodes for this stream have been reset in the middle of the file. This is not supported. The current packet will be discarded.\n"));
     return;
   }
 
@@ -714,6 +711,9 @@ ogm_reader_c::identify() {
     if ((sdemuxers[i]->title != "") && (sdemuxers[i]->stype != OGM_STREAM_TYPE_V_MSCOMP))
       verbose_info.push_back(string("track_name:") + escape(sdemuxers[i]->title));
 
+    if ((0 != sdemuxers[i]->display_width) && (0 != sdemuxers[i]->display_height))
+      verbose_info.push_back((boost::format("display_dimensions:%1%x%2%") % sdemuxers[i]->display_width % sdemuxers[i]->display_height).str());
+
     id_result_track(i, sdemuxers[i]->get_type(), sdemuxers[i]->get_codec(), verbose_info);
   }
 }
@@ -740,7 +740,7 @@ ogm_reader_c::handle_stream_comments() {
 
     int j;
     for (j = 0; comments->size() > j; j++) {
-      mxverb(2, "ogm_reader: commment for #%d for %d: %s\n", j, i, (*comments)[j].c_str());
+      mxverb(2, boost::format("ogm_reader: commment for #%1% for %2%: %3%\n") % j % i % (*comments)[j]);
       vector<string> comment = split((*comments)[j], "=", 2);
       if (comment.size() != 2)
         continue;
@@ -785,23 +785,24 @@ ogm_reader_c::handle_stream_comments() {
     }
 
     if (((title != "") || (chapter_strings.size() > 0)) && !charset_warning_printed && (ti.chapter_charset == "")) {
-      mxwarn("The Ogg/OGM file '%s' contains chapter or title information. Unfortunately the charset used to store this information in "
-             "the file cannot be identified unambiguously. mkvmerge assumes that your system's current charset is appropriate. This can "
-             "be overridden with the '--chapter-charset <charset>' switch.\n", ti.fname.c_str());
+      mxwarn_fn(ti.fname,
+                Y("This Ogg/OGM file contains chapter or title information. Unfortunately the charset used to store this information in "
+                  "the file cannot be identified unambiguously. The program assumes that your system's current charset is appropriate. This can "
+                  "be overridden with the '--chapter-charset <charset>' switch.\n"));
       charset_warning_printed = true;
     }
 
     if (title != "") {
       title = to_utf8(cch, title);
-      if (!segment_title_set && segment_title.empty() && (OGM_STREAM_TYPE_V_MSCOMP == dmx->stype)) {
-        segment_title     = title;
-        segment_title_set = true;
+      if (!g_segment_title_set && g_segment_title.empty() && (OGM_STREAM_TYPE_V_MSCOMP == dmx->stype)) {
+        g_segment_title     = title;
+        g_segment_title_set = true;
       }
       dmx->title = title.c_str();
       title      = "";
     }
 
-    if (!chapter_strings.empty() && !ti.no_chapters && (NULL == kax_chapters)) {
+    if (!chapter_strings.empty() && !ti.no_chapters && (NULL == g_kax_chapters)) {
       try {
         auto_ptr<mm_mem_io_c> out(new mm_mem_io_c(NULL, 0, 1000));
 
@@ -812,7 +813,7 @@ ogm_reader_c::handle_stream_comments() {
 
         auto_ptr<mm_text_io_c> text_out(new mm_text_io_c(out.get(), false));
 
-        kax_chapters = parse_chapters(text_out.get());
+        g_kax_chapters = parse_chapters(text_out.get());
       } catch (...) {
       }
     }
@@ -829,22 +830,23 @@ ogm_reader_c::add_available_track_ids() {
 
 // -----------------------------------------------------------
 
-ogm_demuxer_c::ogm_demuxer_c(ogm_reader_c *p_reader):
-  reader(p_reader),
-  ptzr(-1),
-  stype(OGM_STREAM_TYPE_UNKNOWN),
-  serialno(0),
-  eos(0),
-  units_processed(0),
-  num_header_packets(2),
-  num_non_header_packets(0),
-  headers_read(false),
-  first_granulepos(0),
-  last_granulepos(0),
-  last_keyframe_number(-1),
-  default_duration(0),
-  in_use(false) {
-
+ogm_demuxer_c::ogm_demuxer_c(ogm_reader_c *p_reader)
+  : reader(p_reader)
+  , ptzr(-1)
+  , stype(OGM_STREAM_TYPE_UNKNOWN)
+  , serialno(0)
+  , eos(0)
+  , units_processed(0)
+  , num_header_packets(2)
+  , num_non_header_packets(0)
+  , headers_read(false)
+  , first_granulepos(0)
+  , last_granulepos(0)
+  , default_duration(0)
+  , in_use(false)
+  , display_width(0)
+  , display_height(0)
+{
   memset(&os, 0, sizeof(ogg_stream_state));
 }
 
@@ -902,8 +904,9 @@ ogm_demuxer_c::process_header_page() {
         continue;
       }
 
-      mxwarn("ogm_reader: Missing header/comment packets for stream " LLD " in '%s'. This file is broken but should be muxed correctly. "
-             "If not please contact the author Moritz Bunkus <moritz@bunkus.org>.\n", (int64_t)track_id, reader->ti.fname.c_str());
+      mxwarn_tid(reader->ti.fname, track_id,
+                 Y("Missing header/comment packets for stream. This file is broken but should be muxed correctly. "
+                   "If not please contact the author Moritz Bunkus <moritz@bunkus.org>.\n"));
       headers_read = true;
       ogg_stream_reset(&os);
       return;
@@ -921,9 +924,9 @@ ogm_demuxer_c::process_header_page() {
 
 // -----------------------------------------------------------
 
-ogm_a_aac_demuxer_c::ogm_a_aac_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_a_aac_demuxer_c::ogm_a_aac_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype = OGM_STREAM_TYPE_A_AAC;
 }
 
@@ -947,88 +950,91 @@ ogm_a_aac_demuxer_c::create_packetizer(track_info_c &ti) {
     profile     = AAC_PROFILE_LC;
   }
 
-  mxverb(2, "ogm_reader: " LLD "/%s: profile %d, channels %d, sample_rate %d, sbr %d, output_sample_rate %d\n",
-         ti.id, ti.fname.c_str(), profile, channels, sample_rate, (int)sbr, output_sample_rate);
+  mxverb(2,
+         boost::format("ogm_reader: %1%/%2%: profile %3%, channels %4%, sample_rate %5%, sbr %6%, output_sample_rate %7%\n")
+         % ti.id % ti.fname % profile % channels % sample_rate % sbr % output_sample_rate);
 
-  generic_packetizer_c *ptzr_obj = new aac_packetizer_c(reader, AAC_ID_MPEG4, profile, sample_rate, channels, ti, false, true);
+  generic_packetizer_c *ptzr_obj = new aac_packetizer_c(reader, ti, AAC_ID_MPEG4, profile, sample_rate, channels, false, true);
   if (sbr)
     ptzr_obj->set_audio_output_sampling_freq(output_sample_rate);
 
-  mxinfo(FMT_TID "Using the AAC output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id,  Y("Using the AAC output module.\n"));
 
   return ptzr_obj;
 }
 
 // -----------------------------------------------------------
 
-ogm_a_ac3_demuxer_c::ogm_a_ac3_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_a_ac3_demuxer_c::ogm_a_ac3_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype = OGM_STREAM_TYPE_A_AC3;
 }
 
 generic_packetizer_c *
 ogm_a_ac3_demuxer_c::create_packetizer(track_info_c &ti) {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get() + 1);
-  generic_packetizer_c *ptzr_obj = new ac3_packetizer_c(reader, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), 0, ti);
+  generic_packetizer_c *ptzr_obj = new ac3_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), 0);
 
-  mxinfo(FMT_TID "Using the AC3 output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the AC3 output module.\n"));
 
   return ptzr_obj;
 }
 
 // -----------------------------------------------------------
 
-ogm_a_mp3_demuxer_c::ogm_a_mp3_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_a_mp3_demuxer_c::ogm_a_mp3_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype = OGM_STREAM_TYPE_A_MP3;
 }
 
 generic_packetizer_c *
 ogm_a_mp3_demuxer_c::create_packetizer(track_info_c &ti) {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get() + 1);
-  generic_packetizer_c *ptzr_obj = new mp3_packetizer_c(reader, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), true, ti);
+  generic_packetizer_c *ptzr_obj = new mp3_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), true);
 
-  mxinfo(FMT_TID "Using the MPEG audio output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the MPEG audio output module.\n"));
 
   return ptzr_obj;
 }
 
 // -----------------------------------------------------------
 
-ogm_a_pcm_demuxer_c::ogm_a_pcm_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_a_pcm_demuxer_c::ogm_a_pcm_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype = OGM_STREAM_TYPE_A_PCM;
 }
 
 generic_packetizer_c *
 ogm_a_pcm_demuxer_c::create_packetizer(track_info_c &ti) {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get() + 1);
-  generic_packetizer_c *ptzr_obj = new pcm_packetizer_c(reader, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels),
-                                                    get_uint16_le(&sth->bits_per_sample), ti);
+  generic_packetizer_c *ptzr_obj = new pcm_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels),
+                                                        get_uint16_le(&sth->bits_per_sample));
 
-  mxinfo(FMT_TID "Using the PCM output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the PCM output module.\n"));
 
   return ptzr_obj;
 }
 
 // -----------------------------------------------------------
 
-ogm_a_vorbis_demuxer_c::ogm_a_vorbis_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_a_vorbis_demuxer_c::ogm_a_vorbis_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype              = OGM_STREAM_TYPE_A_VORBIS;
   num_header_packets = 3;
 }
 
 generic_packetizer_c *
 ogm_a_vorbis_demuxer_c::create_packetizer(track_info_c &ti) {
-  generic_packetizer_c *ptzr_obj = new vorbis_packetizer_c(reader, packet_data[0]->get(), packet_data[0]->get_size(), packet_data[1]->get(), packet_data[1]->get_size(),
-                                                           packet_data[2]->get(), packet_data[2]->get_size(), ti);
+  generic_packetizer_c *ptzr_obj = new vorbis_packetizer_c(reader, ti,
+                                                           packet_data[0]->get(), packet_data[0]->get_size(),
+                                                           packet_data[1]->get(), packet_data[1]->get_size(),
+                                                           packet_data[2]->get(), packet_data[2]->get_size());
 
-  mxinfo(FMT_TID "Using the Vorbis output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the Vorbis output module.\n"));
 
   return ptzr_obj;
 }
@@ -1049,17 +1055,17 @@ ogm_a_vorbis_demuxer_c::process_page(int64_t granulepos) {
 
 // -----------------------------------------------------------
 
-ogm_s_text_demuxer_c::ogm_s_text_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_s_text_demuxer_c::ogm_s_text_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype = OGM_STREAM_TYPE_A_AAC;
 }
 
 generic_packetizer_c *
 ogm_s_text_demuxer_c::create_packetizer(track_info_c &ti) {
-  generic_packetizer_c *ptzr_obj = new textsubs_packetizer_c(reader, MKV_S_TEXTUTF8, NULL, 0, true, false, ti);
+  generic_packetizer_c *ptzr_obj = new textsubs_packetizer_c(reader, ti, MKV_S_TEXTUTF8, NULL, 0, true, false);
 
-  mxinfo(FMT_TID "Using the text subtitle output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the text subtitle output module.\n"));
 
   return ptzr_obj;
 }
@@ -1089,9 +1095,9 @@ ogm_s_text_demuxer_c::process_page(int64_t granulepos) {
 
 // -----------------------------------------------------------
 
-ogm_v_avc_demuxer_c::ogm_v_avc_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_v_avc_demuxer_c::ogm_v_avc_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype                  = OGM_STREAM_TYPE_V_AVC;
   num_non_header_packets = 3;
 }
@@ -1100,8 +1106,8 @@ void
 ogm_v_avc_demuxer_c::initialize() {
   stream_header *sth = (stream_header *)(packet_data[0]->get() + 1);
 
-  if (0 > video_fps)
-    video_fps = 10000000.0 / (float)get_uint64_le(&sth->time_unit);
+  if (0 > g_video_fps)
+    g_video_fps = 10000000.0 / (float)get_uint64_le(&sth->time_unit);
 }
 
 generic_packetizer_c *
@@ -1115,15 +1121,15 @@ ogm_v_avc_demuxer_c::create_packetizer(track_info_c &ti) {
     ti.private_size    = 0;
     memory_cptr avcc   = extract_avcc();
 
-    vptzr              = new mpeg4_p10_es_video_packetizer_c(reader, avcc, get_uint32_le(&sth->sh.video.width), get_uint32_le(&sth->sh.video.height), ti);
+    vptzr              = new mpeg4_p10_es_video_packetizer_c(reader, ti, avcc, get_uint32_le(&sth->sh.video.width), get_uint32_le(&sth->sh.video.height));
 
     vptzr->enable_timecode_generation(false);
     vptzr->set_track_default_duration(default_duration);
 
-    mxinfo(FMT_TID "Using the MPEG-4 part 10 ES video output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+    mxinfo_tid(ti.fname, ti.id, Y("Using the MPEG-4 part 10 ES video output module.\n"));
 
   } catch (...) {
-    mxerror(FMT_TID "Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n", ti.fname.c_str(), (int64_t)ti.id);
+    mxerror_tid(ti.fname, ti.id, Y("Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n"));
   }
 
   return vptzr;
@@ -1169,10 +1175,10 @@ ogm_v_avc_demuxer_c::extract_avcc() {
 
 // -----------------------------------------------------------
 
-ogm_v_mscomp_demuxer_c::ogm_v_mscomp_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader),
-  frames_since_granulepos_change(0) {
-
+ogm_v_mscomp_demuxer_c::ogm_v_mscomp_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+  , frames_since_granulepos_change(0)
+{
   stype = OGM_STREAM_TYPE_V_MSCOMP;
 }
 
@@ -1191,8 +1197,8 @@ void
 ogm_v_mscomp_demuxer_c::initialize() {
   stream_header *sth = (stream_header *)(packet_data[0]->get() + 1);
 
-  if (0 > video_fps)
-    video_fps = 10000000.0 / (float)get_uint64_le(&sth->time_unit);
+  if (0 > g_video_fps)
+    g_video_fps = 10000000.0 / (float)get_uint64_le(&sth->time_unit);
 
   default_duration = 100 * get_uint64_le(&sth->time_unit);
 }
@@ -1222,14 +1228,14 @@ ogm_v_mscomp_demuxer_c::create_packetizer(track_info_c &ti) {
 
   generic_packetizer_c *ptzr_obj;
   if (mpeg4::p2::is_fourcc(sth->subtype)) {
-    ptzr_obj = new mpeg4_p2_video_packetizer_c(reader, fps, width, height, false, ti);
+    ptzr_obj = new mpeg4_p2_video_packetizer_c(reader, ti, fps, width, height, false);
 
-    mxinfo(FMT_TID "Using the MPEG-4 part 2 video output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+    mxinfo_tid(ti.fname, ti.id, Y("Using the MPEG-4 part 2 video output module.\n"));
 
   } else {
-    ptzr_obj = new video_packetizer_c(reader, NULL, fps, width, height, ti);
+    ptzr_obj = new video_packetizer_c(reader, ti, NULL, fps, width, height);
 
-    mxinfo(FMT_TID "Using the video output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+    mxinfo_tid(ti.fname, ti.id, Y("Using the video output module.\n"));
   }
 
   ti.private_data = NULL;
@@ -1286,9 +1292,9 @@ ogm_v_mscomp_demuxer_c::process_page(int64_t granulepos) {
 
 // -----------------------------------------------------------
 
-ogm_v_theora_demuxer_c::ogm_v_theora_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_v_theora_demuxer_c::ogm_v_theora_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype              = OGM_STREAM_TYPE_V_THEORA;
   num_header_packets = 3;
 
@@ -1300,8 +1306,11 @@ ogm_v_theora_demuxer_c::initialize() {
   try {
     memory_cptr &mem = packet_data[0];
     theora_parse_identification_header(mem->get(), mem->get_size(), theora);
+
+    display_width  = theora.display_width;
+    display_height = theora.display_height;
   } catch (error_c &e) {
-    mxerror(FMT_TID "The Theora identifaction header could not be parsed (%s).\n", reader->ti.fname.c_str(), track_id, e.get_error().c_str());
+    mxerror_tid(reader->ti.fname, track_id, boost::format(Y("The Theora identifaction header could not be parsed (%1%).\n")) % e.get_error());
   }
 }
 
@@ -1312,9 +1321,9 @@ ogm_v_theora_demuxer_c::create_packetizer(track_info_c &ti) {
   ti.private_size                = codecprivate->get_size();
 
   double                fps      = (double)theora.frn / (double)theora.frd;
-  generic_packetizer_c *ptzr_obj = new video_packetizer_c(reader, MKV_V_THEORA, fps, theora.fmbw, theora.fmbh, ti);
+  generic_packetizer_c *ptzr_obj = new theora_video_packetizer_c(reader, ti, fps, theora.fmbw, theora.fmbh);
 
-  mxinfo(FMT_TID "Using the Theora video output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the Theora video output module.\n"));
 
   ti.private_data = NULL;
 
@@ -1331,24 +1340,18 @@ ogm_v_theora_demuxer_c::process_page(int64_t granulepos) {
     if ((0 == op.bytes) || (0 != (op.packet[0] & 0x80)))
       continue;
 
-    int keyframe_number     = granulepos >> theora.kfgshift;
-    int non_keyframe_number = granulepos &  theora.kfgshift; // TODO: seems wrong
-    // should probably be: // non_keyframe_number = granulepos - (keyframe_number << theora.kfgshift);
-
-    int64_t timecode        = (int64_t)(1000000000.0 * units_processed * theora.frd / theora.frn);
-    int64_t duration        = (int64_t)(1000000000.0 *                   theora.frd / theora.frn);
-    int64_t bref            = (keyframe_number != last_keyframe_number) && (0 == non_keyframe_number) ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC;
-
-    reader->reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false), timecode, duration, bref, VFT_NOBFRAME));
+    bool is_keyframe = 0x00 == (op.packet[0] & 0x40);
+    int64_t timecode = (int64_t)(1000000000.0 * units_processed * theora.frd / theora.frn);
+    int64_t duration = (int64_t)(1000000000.0 *                   theora.frd / theora.frn);
+    int64_t bref     = is_keyframe ? VFT_IFRAME : VFT_PFRAMEAUTOMATIC;
 
     ++units_processed;
 
-    last_keyframe_number = keyframe_number;
+    reader->reader_packetizers[ptzr]->process(new packet_t(new memory_c(op.packet, op.bytes, false), timecode, duration, bref, VFT_NOBFRAME));
 
-    if (op.e_o_s) {
-      eos = 1;
-      return;
-    }
+    mxverb(3,
+           boost::format("Theora track %1% kfgshift %2% granulepos 0x%|3$08x| %|4$08x|%5%\n")
+           % track_id % theora.kfgshift % (granulepos >> 32) % (granulepos & 0xffffffff) % (is_keyframe ? " key" : ""));
   }
 }
 
@@ -1359,9 +1362,9 @@ ogm_v_theora_demuxer_c::is_header_packet(ogg_packet &op) {
 
 // -----------------------------------------------------------
 
-ogm_s_kate_demuxer_c::ogm_s_kate_demuxer_c(ogm_reader_c *p_reader):
-  ogm_demuxer_c(p_reader) {
-
+ogm_s_kate_demuxer_c::ogm_s_kate_demuxer_c(ogm_reader_c *p_reader)
+  : ogm_demuxer_c(p_reader)
+{
   stype              = OGM_STREAM_TYPE_S_KATE;
   num_header_packets = 1; /* at least 1, will be updated upon reading the ID header */
 
@@ -1375,7 +1378,7 @@ ogm_s_kate_demuxer_c::initialize() {
     kate_parse_identification_header(mem->get(), mem->get_size(), kate);
     num_header_packets = kate.nheaders;
   } catch (error_c &e) {
-    mxerror(FMT_TID "The Kate identifaction header could not be parsed (%s).\n", reader->ti.fname.c_str(), track_id, e.get_error().c_str());
+    mxerror_tid(reader->ti.fname, track_id, boost::format(Y("The Kate identifaction header could not be parsed (%1%).\n")) % e.get_error());
   }
 }
 
@@ -1385,9 +1388,9 @@ ogm_s_kate_demuxer_c::create_packetizer(track_info_c &ti) {
   ti.private_data                = codecprivate->get();
   ti.private_size                = codecprivate->get_size();
 
-  generic_packetizer_c *ptzr_obj = new kate_packetizer_c(reader, ti.private_data, ti.private_size, ti);
+  generic_packetizer_c *ptzr_obj = new kate_packetizer_c(reader, ti, ti.private_data, ti.private_size);
 
-  mxinfo(FMT_TID "Using the Kate subtitle output module.\n", ti.fname.c_str(), (int64_t)ti.id);
+  mxinfo_tid(ti.fname, ti.id, Y("Using the Kate subtitle output module.\n"));
 
   ti.private_data = NULL;
 
