@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mkvmerge.h 3923 2008-09-21 14:31:14Z mosu $
-
    definition of global variables found in mkvmerge.cpp
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -19,12 +17,6 @@
 
 #include "pr_generic.h"
 
-enum display_priority_e {
-  DISPLAYPRIORITY_LOW,
-  DISPLAYPRIORITY_MEDIUM,
-  DISPLAYPRIORITY_HIGH
-};
-
 /* file types */
 enum file_type_e {
   FILE_TYPE_IS_UNKNOWN = 0,
@@ -33,6 +25,7 @@ enum file_type_e {
   FILE_TYPE_ASF,
   FILE_TYPE_AVC_ES,
   FILE_TYPE_AVI,
+  FILE_TYPE_CDXA,
   FILE_TYPE_CHAPTERS,
   FILE_TYPE_COREPICTURE,
   FILE_TYPE_DIRAC,
