@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: pr_generic.cpp 3978 2008-10-09 07:50:55Z mosu $
-
    functions common for all readers/packetizers
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -45,7 +43,6 @@ using namespace std;
    : track_video == track_type ? DEFTRACK_TYPE_VIDEO \
    :                             DEFTRACK_TYPE_SUBS)
 
-
 int64_t packet_t::sm_packet_number_counter = 0;
 
 packet_t::~packet_t() {
@@ -180,11 +177,12 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *p_reader,
       ti.aspect_ratio_is_factor   = dprop.ar_factor;
     }
   }
-  if (ti.aspect_ratio_given && ti.display_dimensions_given)
+  if (ti.aspect_ratio_given && ti.display_dimensions_given) {
     if (ti.aspect_ratio_is_factor)
       mxerror_tid(ti.fname, ti.id, boost::format(Y("Both the aspect ratio factor and '--display-dimensions' were given.\n")));
     else
       mxerror_tid(ti.fname, ti.id, boost::format(Y("Both the aspect ratio and '--display-dimensions' were given.\n")));
+  }
 
   // Let's see if the user has specified a FourCC for this track.
   if (map_has_key(ti.all_fourccs, ti.id))
@@ -578,12 +576,10 @@ generic_packetizer_c::set_headers() {
     KaxTrackVideo &video = GetChild<KaxTrackVideo>(track_entry);
 
     if ((-1 != hvideo_pixel_height) && (-1 != hvideo_pixel_width)) {
-      int disp_width, disp_height;
-
       if ((-1 == hvideo_display_width) || (-1 == hvideo_display_height) || ti.aspect_ratio_given || ti.display_dimensions_given) {
         if (ti.display_dimensions_given) {
-          disp_width  = ti.display_width;
-          disp_height = ti.display_height;
+          hvideo_display_width  = ti.display_width;
+          hvideo_display_height = ti.display_height;
 
         } else {
           if (!ti.aspect_ratio_given)
@@ -593,25 +589,21 @@ generic_packetizer_c::set_headers() {
             ti.aspect_ratio = (float)hvideo_pixel_width * ti.aspect_ratio / (float)hvideo_pixel_height;
 
           if (ti.aspect_ratio > ((float)hvideo_pixel_width / (float)hvideo_pixel_height)) {
-            disp_width  = irnd(hvideo_pixel_height * ti.aspect_ratio);
-            disp_height = hvideo_pixel_height;
+            hvideo_display_width  = irnd(hvideo_pixel_height * ti.aspect_ratio);
+            hvideo_display_height = hvideo_pixel_height;
 
           } else {
-            disp_width  = hvideo_pixel_width;
-            disp_height = irnd(hvideo_pixel_width / ti.aspect_ratio);
+            hvideo_display_width  = hvideo_pixel_width;
+            hvideo_display_height = irnd(hvideo_pixel_width / ti.aspect_ratio);
           }
         }
-
-      } else {
-        disp_width  = hvideo_display_width;
-        disp_height = hvideo_display_height;
       }
 
       GetChildAs<KaxVideoPixelWidth,    EbmlUInteger>(video) = hvideo_pixel_width;
       GetChildAs<KaxVideoPixelHeight,   EbmlUInteger>(video) = hvideo_pixel_height;
 
-      GetChildAs<KaxVideoDisplayWidth,  EbmlUInteger>(video) = disp_width;
-      GetChildAs<KaxVideoDisplayHeight, EbmlUInteger>(video) = disp_height;
+      GetChildAs<KaxVideoDisplayWidth,  EbmlUInteger>(video) = hvideo_display_width;
+      GetChildAs<KaxVideoDisplayHeight, EbmlUInteger>(video) = hvideo_display_height;
 
       GetChild<KaxVideoDisplayWidth>(video).SetDefaultSize(4);
       GetChild<KaxVideoDisplayHeight>(video).SetDefaultSize(4);
@@ -947,13 +939,13 @@ generic_packetizer_c::apply_factory_full_queueing(packet_cptr_di &p_start) {
 void
 generic_packetizer_c::force_duration_on_last_packet() {
   if (packet_queue.empty()) {
-    mxverb_tid(2, ti.fname, ti.id, Y("force_duration_on_last_packet: packet queue is empty\n"));
+    mxverb_tid(2, ti.fname, ti.id, "force_duration_on_last_packet: packet queue is empty\n");
     return;
   }
   packet_cptr &packet        = packet_queue.back();
   packet->duration_mandatory = true;
   mxverb_tid(2, ti.fname, ti.id,
-             boost::format(Y("force_duration_on_last_packet: forcing at %1% with %|2$.3f|ms\n")) % format_timecode(packet->timecode) % (packet->duration / 1000.0));
+             boost::format("force_duration_on_last_packet: forcing at %1% with %|2$.3f|ms\n") % format_timecode(packet->timecode) % (packet->duration / 1000.0));
 }
 
 int64_t
@@ -1373,6 +1365,10 @@ track_info_c::track_info_c()
   , no_chapters(false)
   , no_attachments(false)
   , no_tags(false)
+  , avi_block_align(0)
+  , avi_samples_per_sec(0)
+  , avi_avg_bytes_per_sec(0)
+  , avi_samples_per_chunk(0)
   , avi_audio_sync_enabled(false)
 {
   memset(&pixel_cropping, 0, sizeof(pixel_crop_t));
