@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: pr_generic.h 3978 2008-10-09 07:50:55Z mosu $
-
    class definition for the generic reader and packetizer
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -353,20 +351,20 @@ enum connection_result_e {
     error_message = (boost::format(Y("The number of bits per sample of the two audio tracks is different: %1% and %2%")) % (a) % (b)).str(); \
     return CAN_CONNECT_NO_PARAMETERS;                                                                                                        \
   }
-#define connect_check_v_width(a, b)                                                                                 \
-  if ((a) != (b)) {                                                                                                 \
-    error_message = (boost::format(Y("The width of the two  tracks is different: %1% and %2%")) % (a) % (b)).str(); \
-    return CAN_CONNECT_NO_PARAMETERS;                                                                               \
+#define connect_check_v_width(a, b)                                                                                \
+  if ((a) != (b)) {                                                                                                \
+    error_message = (boost::format(Y("The width of the two tracks is different: %1% and %2%")) % (a) % (b)).str(); \
+    return CAN_CONNECT_NO_PARAMETERS;                                                                              \
   }
 #define connect_check_v_height(a, b)                                                                                \
   if ((a) != (b)) {                                                                                                 \
     error_message = (boost::format(Y("The height of the two tracks is different: %1% and %2%")) % (a) % (b)).str(); \
     return CAN_CONNECT_NO_PARAMETERS;                                                                               \
   }
-#define connect_check_v_dwidth(a, b)                                                                                        \
-  if ((a) != (b)) {                                                                                                         \
-    error_message = (boost::format(Y("The display width of the two  tracks is different: %1% and %2%")) % (a) % (b)).str(); \
-    return CAN_CONNECT_NO_PARAMETERS;                                                                                       \
+#define connect_check_v_dwidth(a, b)                                                                                       \
+  if ((a) != (b)) {                                                                                                        \
+    error_message = (boost::format(Y("The display width of the two tracks is different: %1% and %2%")) % (a) % (b)).str(); \
+    return CAN_CONNECT_NO_PARAMETERS;                                                                                      \
   }
 #define connect_check_v_dheight(a, b)                                                                                       \
   if ((a) != (b)) {                                                                                                         \
