@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mmg.h 2965 2005-06-24 14:58:13Z mosu $
-
    main stuff - declarations
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -23,6 +21,7 @@
 
 #include "wx/string.h"
 #include "wx/app.h"
+#include "wx/combobox.h"
 
 #include "ebml/EbmlUnicodeString.h"
 
@@ -31,15 +30,17 @@
 #include "wxcommon.h"
 
 #ifdef SYS_WINDOWS
-#define ALLFILES "All Files (*.*)|*.*"
-#define PSEP '\\'
-#define YOFF (-4)
-#define YOFF2 0
+# define ALLFILES Z("All Files (*.*)|*.*")
+# define PSEP '\\'
+# define STDSPACING 3
+# define TOPBOTTOMSPACING 5
+# define LEFTRIGHTSPACING 5
 #else
-#define ALLFILES "All Files (*)|*"
-#define PSEP '/'
-#define YOFF (-2)
-#define YOFF2 (-3)
+# define ALLFILES Z("All Files (*)|*")
+# define PSEP '/'
+# define STDSPACING 3
+# define TOPBOTTOMSPACING 5
+# define LEFTRIGHTSPACING 5
 #endif
 
 #define MMG_CONFIG_FILE_VERSION_MAX 2
@@ -54,19 +55,28 @@ struct mmg_track_t {
   wxString ctype;
   bool enabled, display_dimensions_selected;
 
-  bool default_track, aac_is_sbr;
+  int default_track;
+  bool aac_is_sbr, aac_is_sbr_detected;
   bool track_name_was_present;
   wxString language, track_name, cues, delay, stretch, sub_charset;
-  wxString tags, fourcc, aspect_ratio, compression, timecodes;
+  wxString tags, fourcc, aspect_ratio, compression, timecodes, fps;
+  wxString packetizer;
+  int nalu_size_length;
   wxString dwidth, dheight;
+  int stereo_mode;
+
+  wxString user_defined;
 
   bool appending;
 
   mmg_track_t():
     type(0), id(0), source(0),
     enabled(false), display_dimensions_selected(false),
-    default_track(false), aac_is_sbr(false), track_name_was_present(false),
+    default_track(0), aac_is_sbr(false), aac_is_sbr_detected(false),
+    track_name_was_present(false),
     language(wxT("und")), cues(wxT("default")), sub_charset(wxT("default")),
+    nalu_size_length(0),
+    stereo_mode(0),
     appending(false) {};
 };
 typedef counted_ptr<mmg_track_t> mmg_track_ptr;
@@ -87,7 +97,7 @@ struct mmg_file_t {
 typedef counted_ptr<mmg_file_t> mmg_file_ptr;
 
 struct mmg_attachment_t {
-  wxString file_name, description, mime_type;
+  wxString file_name, stored_name, description, mime_type;
   int style;
 
   mmg_attachment_t():
@@ -95,8 +105,38 @@ struct mmg_attachment_t {
 };
 typedef counted_ptr<mmg_attachment_t> mmg_attachment_ptr;
 
+typedef enum {
+  ODM_FROM_FIRST_INPUT_FILE = 0,
+  ODM_PREVIOUS              = 1,
+  ODM_FIXED                 = 2,
+} output_directory_mode_e;
+
+struct mmg_options_t {
+  wxString mkvmerge;
+  wxString output_directory;
+  bool autoset_output_filename;
+  output_directory_mode_e output_directory_mode;
+  bool ask_before_overwriting;
+  bool on_top;
+  bool filenew_after_add_to_jobqueue;
+  bool warn_usage;
+  bool gui_debugging;
+  bool always_use_simpleblock;
+  bool set_delay_from_filename;
+  wxString priority;
+
+  mmg_options_t():
+    autoset_output_filename(false), output_directory_mode(ODM_FROM_FIRST_INPUT_FILE),
+    ask_before_overwriting(false),
+    on_top(false), filenew_after_add_to_jobqueue(false),
+    warn_usage(false), gui_debugging(false), always_use_simpleblock(false),
+    set_delay_from_filename(false) {
+  }
+
+  void validate();
+};
+
 extern wxString last_open_dir;
-extern wxString mkvmerge_path;
 extern vector<wxString> last_settings;
 extern vector<wxString> last_chapters;
 extern vector<mmg_file_t> files;
@@ -126,13 +166,15 @@ wxString create_track_order(bool all);
 
 int default_track_checked(char type);
 
+void set_combobox_selection(wxComboBox *cb, const wxString wanted);
+
 void wxdie(const wxString &errmsg);
 
 #if defined(SYS_WINDOWS)
-#define TIP(s) format_tooltip(wxT(s))
+#define TIP(s) format_tooltip(wxU(s))
 wxString format_tooltip(const wxString &s);
 #else
-#define TIP(s) wxT(s)
+#define TIP(s) wxU(s)
 #endif
 
 class mmg_app: public wxApp {
