@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_video.cpp 3950 2008-09-30 22:35:14Z mosu $
-
    video output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -25,6 +23,7 @@
 #include "mpeg4_common.h"
 #include "output_control.h"
 #include "p_video.h"
+#include "theora_common.h"
 
 extern "C" {
 #include <avilib.h>
@@ -502,7 +501,7 @@ mpeg4_p2_video_packetizer_c::flush_frames_maybe(frame_type_e next_frame) {
 
   int num_bframes = 0;
   int i;
-  for (i = 0; m_queued_frames.size() > 0; ++i)
+  for (i = 0; m_queued_frames.size() > i; ++i)
     if (FRAME_TYPE_B == m_queued_frames[i].type)
       ++num_bframes;
 
@@ -535,12 +534,12 @@ mpeg4_p2_video_packetizer_c::handle_missing_timecodes(bool end_of_file) {
     while (m_available_timecodes.size() < m_queued_frames.size()) {
       m_previous_timecode = (int64_t)(m_previous_timecode +  1000000000.0 / m_fps);
       m_available_timecodes.push_back(m_previous_timecode);
-      mxverb(3, boost::format(Y("mpeg4_p2::flush_frames(): Needed new timecode %1%\n")) % m_previous_timecode);
+      mxverb(3, boost::format("mpeg4_p2::flush_frames(): Needed new timecode %1%\n") % m_previous_timecode);
     }
 
     while (m_available_durations.size() < m_queued_frames.size()) {
       m_available_durations.push_back((int64_t)(1000000000.0 / m_fps));
-      mxverb(3, boost::format(Y("mpeg4_p2::flush_frames(): Needed new duration %1%\n")) % m_available_durations.back());
+      mxverb(3, boost::format("mpeg4_p2::flush_frames(): Needed new duration %1%\n") % m_available_durations.back());
     }
 
     return;
@@ -647,7 +646,7 @@ mpeg4_p2_video_packetizer_c::extract_aspect_ratio(const unsigned char *buffer,
     rerender_track_headers();
     mxinfo_tid(ti.fname, ti.id,
                boost::format(Y("Extracted the aspect ratio information from the MPEG4 layer 2 video data and set the display dimensions to %1%/%2%.\n"))
-               % ti.display_width % ti.display_height);
+               % hvideo_display_width % hvideo_display_height);
 
   } else if (50 <= m_frames_output)
     m_aspect_ratio_extracted = true;
@@ -672,6 +671,9 @@ mpeg4_p2_video_packetizer_c::extract_size(const unsigned char *buffer,
         set_codec_private(ti.private_data, ti.private_size);
       }
 
+      hvideo_display_width  = -1;
+      hvideo_display_height = -1;
+
       generic_packetizer_c::set_headers();
       rerender_track_headers();
 
@@ -790,7 +792,7 @@ mpeg4_p10_video_packetizer_c::setup_nalu_size_len_change() {
 
   set_codec_private(ti.private_data, ti.private_size);
 
-  mxverb(2, boost::format(Y("mpeg4_p10: Adjusting NALU size length from %1% to %2%\n")) % m_nalu_size_len_src % m_nalu_size_len_dst);
+  mxverb(2, boost::format("mpeg4_p10: Adjusting NALU size length from %1% to %2%\n") % m_nalu_size_len_src % m_nalu_size_len_dst);
 }
 
 void
@@ -867,6 +869,12 @@ theora_video_packetizer_c(generic_reader_c *p_reader,
 {
 }
 
+void
+theora_video_packetizer_c::set_headers() {
+  extract_aspect_ratio();
+  video_packetizer_c::set_headers();
+}
+
 int
 theora_video_packetizer_c::process(packet_cptr packet) {
   if (packet->data->get_size() && (0x00 == (packet->data->get()[0] & 0x40)))
@@ -879,3 +887,36 @@ theora_video_packetizer_c::process(packet_cptr packet) {
   return video_packetizer_c::process(packet);
 }
 
+void
+theora_video_packetizer_c::extract_aspect_ratio() {
+  if (ti.display_dimensions_given || ti.aspect_ratio_given || (NULL == ti.private_data) || (0 == ti.private_size))
+    return;
+
+  memory_cptr private_data         = memory_cptr(new memory_c(ti.private_data, ti.private_size, false));
+  std::vector<memory_cptr> packets = unlace_memory_xiph(private_data);
+
+  std::vector<memory_cptr>::iterator i;
+  mxforeach(i, packets) {
+    if ((0 == (*i)->get_size()) || (THEORA_HEADERTYPE_IDENTIFICATION != (*i)->get()[0]))
+      continue;
+
+    try {
+      theora_identification_header_t theora;
+      theora_parse_identification_header((*i)->get(), (*i)->get_size(), theora);
+
+      if ((0 == theora.display_width) || (0 == theora.display_height))
+        return;
+
+      ti.display_dimensions_given = true;
+      ti.display_width            = theora.display_width;
+      ti.display_height           = theora.display_height;
+
+      mxinfo_tid(ti.fname, ti.id,
+                 boost::format(Y("Extracted the aspect ratio information from the Theora video headers and set the display dimensions to %1%/%2%.\n"))
+                 % theora.display_width % theora.display_height);
+    } catch (...) {
+    }
+
+    return;
+  }
+}
